[dts] [PATCH V2 2/7] framework/dut: fix logger quit issue

yufengmx yufengx.mo at intel.com
Mon Sep 23 08:50:35 CEST 2019


*. move dut logger close after session close for logger used by session.
*. fix typo.

Signed-off-by: yufengmx <yufengx.mo at intel.com>
---
 framework/dut.py | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/framework/dut.py b/framework/dut.py
index 1779d3a..a394b34 100644
--- a/framework/dut.py
+++ b/framework/dut.py
@@ -208,7 +208,7 @@ class Dut(Crb):
         self.restore_interfaces()
         # rescan ports after interface up
         self.rescan_ports()
         # load port infor from config file
         self.load_portconf()
         self.mount_procfs()
         # auto detect network topology
@@ -933,8 +933,8 @@ class Dut(Crb):
 
     def load_portconf(self):
         """
-        Load port configurations for ports_info. If manually configured infor
-        not same as auto scanned, still use infor in configuration file.
+        Load port configurations for ports_info. If manually configured info
+        not same as auto scanned, still use information in configuration file.
         """
         for port in self.ports_info:
             pci_bus = port['pci']
@@ -1097,6 +1097,6 @@ class Dut(Crb):
         """
         Recover all resource before crb exit
         """
-        self.logger.logger_exit()
         self.enable_tester_ipv6()
         self.close()
+        self.logger.logger_exit()
@@ -208,7 +208,7 @@ class Dut(Crb):
         # rescan ports after interface up
         self.rescan_ports()
-        # load port infor from config file
+        # load port information from config file
         self.load_portconf()
         self.mount_procfs()
-- 
2.21.0



More information about the dts mailing list